@rem ************************************************************************
@rem  Licensed Material - Property of IBM
@rem 
@rem  5724-M24 
@rem 
@rem  (c) Copyright IBM Corp. 2006,2007.  All rights reserved.
@rem 
@rem  US Government Users Restricted Rights - Use, duplication or
@rem  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@rem ************************************************************************

@rem ***********************************************************
@rem Update Monitor Dashboard 6.0.2.1 to iFix3 Level
@rem ***********************************************************
@echo off
setlocal
set SAVE_RC=0
@rem Set up logs directory
SET MY_DIR=%CD%
if exist "%MY_DIR%\logs" goto setlog 
mkdir "%MY_DIR%\logs"
:setlog
set MY_LOG="%MY_DIR%\logs\dashboard.log"

@rem Define fixpack specific variables
set MON_FIXPACK_LEVEL=iFix3
set MON_FIXPACK=6.0.2.1-WBI-MONITOR-%MON_FIXPACK_LEVEL%
set MON_FIXPACK_INST=%MON_FIXPACK%.install
set MON_FIXPACK_BACKUP=%MON_FIXPACK_INST%\backups\dashboard
set MON_FIXPACK_STAMP=%MON_FIXPACK%.version

echo Start Monitor Dashboard 6.0.2.1 %MON_FIXPACK_LEVEL% update...
call :logecho "Start Monitor Dashboard 6.0.2.1 %MON_FIXPACK_LEVEL% update..."

@rem Set defaults 
set MY_DRIVE=C:
set PROFILE_NAME=wp_profile
set MON_HOME=%MY_DRIVE%\IBM\WebSphere\Monitor
if not "%WBMONITOR_HOME%"=="" set MON_HOME=%WBMONITOR_HOME%
set WAS_HOME=%MY_DRIVE%\IBM\WAS
set WPS_HOME=%MY_DRIVE%\IBM\PortalServer
set PROFILE_HOME=%WAS_HOME%\profiles\%PROFILE_NAME%
set PORTAL_SERVER=WebSphere_Portal
set ADMIN_ID=wpsadmin
set ADMIN_PW=wpsadmin
set CONFIG_HOST=localhost
set CONFIG_PORT=9081

@rem Define input prompts       
set MON_HOME_PROMPT=Type the path to the WebSphere Business Monitor installation directory
set WAS_HOME_PROMPT=Type the path to the WebSphere Application Server installation directory
set PROFILE_PROMPT=Type the path to the profile that the contains the Portal Server
set PORTAL_HOME_PROMPT=Type the path to the Portal Server installation directory
set CONFIG_PORT_PROMPT=Type the port number used to access the WebSphere Portal configuration utility 
set WPS_ID_PROMPT=Type the user ID for the Portal Admin user 
set WPS_PW_PROMPT=Type the password for the Portal Admin user 

@rem Get Monitor home
set RESPONSE=
set /p RESPONSE=%MON_HOME_PROMPT% [enter=%MON_HOME%]: 
if not "%RESPONSE%"=="" set MON_HOME=%RESPONSE%
if not exist "%MON_HOME%" goto badMonHome

@rem Get WAS variables
set RESPONSE=
set /p RESPONSE=%WAS_HOME_PROMPT% [enter=%WAS_HOME%]: 
if not "%RESPONSE%"=="" set WAS_HOME=%RESPONSE%
if not exist "%WAS_HOME%" goto badWasHome
set PROFILE_HOME=%WAS_HOME%\profiles\%PROFILE_NAME%
set RESPONSE=
set /p RESPONSE=%PROFILE_PROMPT% [enter=%PROFILE_HOME%]:
if not "%RESPONSE%"=="" set PROFILE_HOME=%RESPONSE%
if not exist "%PROFILE_HOME%" goto badProfileHome

@rem Get Portal variables
set RESPONSE=
set /p RESPONSE=%PORTAL_HOME_PROMPT% [enter=%WPS_HOME%]:
if not "%RESPONSE%"=="" set WPS_HOME=%RESPONSE%
if not exist "%WPS_HOME%" goto badPortalHome
set RESPONSE=
set /p RESPONSE=%WPS_ID_PROMPT% [enter=%ADMIN_ID%]:
if not "%RESPONSE%"=="" set ADMIN_ID=%RESPONSE%
set RESPONSE=
set /p RESPONSE=%WPS_PW_PROMPT% [enter=%ADMIN_PW%]:
if not "%RESPONSE%"=="" set ADMIN_PW=%RESPONSE%
set RESPONSE=
set /p RESPONSE=%CONFIG_PORT_PROMPT% [enter=%CONFIG_PORT%]:
if not "%RESPONSE%"=="" set CONFIG_PORT=%RESPONSE%
set CONFIG_URL=http://%CONFIG_HOST%:%CONFIG_PORT%/wps/config

:checkstamp
@rem ************************************************************************
@rem Look for stamp for this level in Monitor home; if found and backup
@rem directory is present then this level is already installed
@rem ************************************************************************
set MON_FIXPACK_DIR=%MON_HOME%\update\%MON_FIXPACK_INST%
echo %MON_FIXPACK_DIR%
if exist %MON_FIXPACK_DIR%\%MON_FIXPACK_STAMP% goto checkbackup
goto stopserver
:checkbackup
if not exist %MON_FIXPACK_DIR%\backups\dashboard goto stopserver
echo This fixpack level (%MON_FIXPACK%) has already been installed for the Dashboard.
call :logecho "This fixpack level (%MON_FIXPACK%) has already been installed for the Dashboard."
goto fatal

:stopserver
@rem ************************************************************************
@rem Stop the Portal server
@rem ************************************************************************
echo Stopping server %PORTAL_SERVER%...
call :logecho "Stopping server %PORTAL_SERVER%..."
set CMD="%PROFILE_HOME%\bin\stopServer.bat" %PORTAL_SERVER% -username "%ADMIN_ID%" -password "%ADMIN_PW%"
call %CMD% >>%MY_LOG% 2>&1 

:createbackupdir
@rem *********************************************************
@rem Create directory for backing up files to be replaced
@rem *********************************************************
if exist "%MON_FIXPACK_BACKUP%" goto startupdate
set CMD=mkdir "%MON_FIXPACK_BACKUP%"
%CMD% >>%MY_LOG% 2>&1 
if %errorlevel% NEQ 0 goto cmdFailed

:startupdate
@rem *********************************************************
@rem Update jar files in WAS directory
@rem *********************************************************
echo Updating server jar files...
call :logecho "Updating server jar files..."
for %%f in (jars\*.*) do call :backupandreplace %%f "%WAS_HOME%"\lib
if %errorlevel% NEQ 0 goto cmdFailed

goto end

@rem ************************************************************************
@rem **************** Begin function definitions ****************************
REM ----------------------------------------------------------------------
REM  logecho
REM 
REM  write messages to log file
REM ----------------------------------------------------------------------
:logecho
echo ******************************************************** >> %MY_LOG% 
echo %~1 >> %MY_LOG% 
echo ******************************************************** >> %MY_LOG% 
time /t >>%MY_LOG% 
GOTO :EOF

REM ----------------------------------------------------------------------
REM  backupandreplace
REM
REM  Back up file being replaced, then copy in new one
REM  Don't copy file that doesn't exist
REM ----------------------------------------------------------------------
:backupandreplace
if not exist "%2"\%~nx1 goto backupandreplaceend
if not exist "%MON_FIXPACK_BACKUP%"\%~nx1 goto backup
echo Backup already created for %~nx1, don't overwrite >>%MY_LOG%
goto replace
:backup
set CMD=Xcopy /F /R /Y "%2"\%~nx1 "%MON_FIXPACK_BACKUP%"
%CMD% >>%MY_LOG% 2>&1
:replace
set CMD=XCopy /F /R /Y "%1" "%2"
%CMD% >>%MY_LOG% 2>&1
:backupandreplaceend
GOTO :EOF
REM ----------------------------------------------------------------------
@rem **************** End function definitions ******************************
@rem ************************************************************************

@rem ************************************************************************
@rem Error messages start here
@rem ************************************************************************
:badProfileHome
echo Error: Profile home - "%PROFILE_HOME%" does not exist >>%MY_LOG%
goto fatal
:badWasHome
echo Error: WAS home - "%WAS_HOME%" does not exist >>%MY_LOG%
goto fatal
:badPortalHome
echo Error: Portal home - "%WPS_HOME%" does not exist >>%MY_LOG%
goto fatal
:badMonHome
echo Error: Monitor home - "%MON_HOME%" does not exist >>%MY_LOG%
set MON_HOME=
goto fatal
:cmdFailed
set SAVE_RC=%errorlevel%
echo Error: '%CMD%' returned %SAVE_RC% >>%MY_LOG%
goto fatal

:fatal
set SAVE_RC=8
goto failed
:warning 
set SAVE_RC=4
goto failed

@rem ************************************************************************
:failed
@rem ************************************************************************
echo Update failed! 
call :logecho "Update failed!"
goto end2

@rem ************************************************************************
:end
@rem ************************************************************************
@rem Copy our stamp file to mark successful update to this level,
@rem then copy stamp and backups to Monitor home
@rem ************************************************************************
set CMD=XCopy /F /R /Y "version\*.*" "%MON_FIXPACK_INST%\"
%CMD% >>%MY_LOG% 2>&1
echo Copying backups and version info to Monitor home.
call :logecho "Copying backups and version info to Monitor home."
set MON_FIXPACK_DIR=%MON_HOME%\update\%MON_FIXPACK_INST%
if exist "%MON_FIXPACK_DIR%" goto copybackups
mkdir "%MON_FIXPACK_DIR%"
:copybackups
set CMD=Xcopy /F /R /Y /S "%MON_FIXPACK_INST%" "%MON_FIXPACK_DIR%\"
%CMD% >>%MY_LOG% 2>&1

@rem ************************************************************************
@rem Restart the Portal server
@rem ************************************************************************
echo Starting server %PORTAL_SERVER%...
call :logecho "Starting server %PORTAL_SERVER%..."
set CMD="%PROFILE_HOME%\bin\startServer.bat" %PORTAL_SERVER% -username "%ADMIN_ID%" -password "%ADMIN_PW%"
call %CMD% >>%MY_LOG% 2>&1 
if %errorlevel% NEQ 0 goto cmdFailed

@rem ************************************************************************
:done
echo Update finished.
call :logecho "Update finished."
:end2

@rem Copy log file to Monitor home
IF ".%MON_HOME%"=="." goto skipcopy
set MON_LOG_DIR=%MON_HOME%\update\%MON_FIXPACK_INST%\logs
if exist "%MON_LOG_DIR%" goto copylog 
mkdir "%MON_LOG_DIR%"
:copylog
xcopy /F /R /Y %MY_LOG% "%MON_LOG_DIR%\" >>nul 2>&1

:skipcopy
exit /b %SAVE_RC%
endlocal
