@rem ************************************************************************
@rem  Licensed Material - Property of IBM
@rem 
@rem  5724-M24 
@rem 
@rem  (c) Copyright IBM Corp. 2006,2007.  All rights reserved.
@rem 
@rem  US Government Users Restricted Rights - Use, duplication or
@rem  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@rem ************************************************************************

@rem ************************************************************************
@rem Update Monitor Server 6.0.2.1 to iFix3 level
@rem ************************************************************************

@echo off
@rem ************************************************************************
@rem For a Toolkit update, a parm is passed to this program
@rem In that case, don't setlocal so that the dir vars
@rem are available to the calling program
@rem ************************************************************************
SET INST_TK=no
IF ".%1"=="." goto noTK
SET INST_TK=yes
goto skiploc
:noTK
setlocal
:skiploc
set SAVE_RC=0
@rem Set up logs directory
SET MY_DIR=%CD%
if exist "%MY_DIR%\logs" goto setlog 
mkdir "%MY_DIR%\logs"
:setlog
set MY_LOG="%MY_DIR%\logs\monsrv.log"

@rem Define fixpack specific variables
set MON_FIXPACK_LEVEL=iFix3
set MON_FIXPACK=6.0.2.1-WBI-MONITOR-%MON_FIXPACK_LEVEL%
set MON_FIXPACK_INST=%MON_FIXPACK%.install
set MON_FIXPACK_BACKUP=%MON_FIXPACK_INST%\backups\monsrv
set MON_FIXPACK_STAMP=%MON_FIXPACK%.version

echo Start Monitor Server 6.0.2.1 %MON_FIXPACK_LEVEL% update...
call :logecho "Start Monitor Server 6.0.2.1 %MON_FIXPACK_LEVEL% update..."

@rem Monitor Server and Toolkit have different prompts
if "%INST_TK%"=="yes" goto tkPrompt

@rem Define input prompts for Monitor Server
set MON_PROMPT=Type the path to the WebSphere Business Monitor installation directory
set WAS_PROMPT=Type the path to the Process Server installation directory
set PROFILE_PROMPT=Type the path to the Process Server profile directory
set DMGR_PROMPT=Is this update running on an ND Deployment Manager? Type y or n
set SERVER_PROMPT=Type the server name

@rem Define default values for Monitor Server standalone server and deployment manager
set MON_HOME=C:\IBM\WebSphere\Monitor
if not "%WBMONITOR_HOME%"=="" set MON_HOME=%WBMONITOR_HOME%
@rem setupCmdLine.bat sets WAS_HOME which overrides our value, so use WAS_HOME1
set WAS_HOME1=C:\IBM\WebSphere\ProcServer
set WAS_PROFILE_NAME=wbmonitor
set WAS_SERVER_NAME=server1
set DMGR_PROFILE_NAME=dmgr
set DMGR_SERVER_NAME=dmgr

@rem Ask if DMgr is being updated       
:askdmgr
set DMGR_UPGRADE=x
set INPUT=
set /p INPUT=%DMGR_PROMPT% : 
IF "%INPUT%"=="y" (
set DMGR_UPGRADE=%INPUT%
set PROFILE_NAME1=%DMGR_PROFILE_NAME%
set SERVER_NAME1=%DMGR_SERVER_NAME%
)
IF "%INPUT%"=="n" (
set DMGR_UPGRADE=%INPUT%
set PROFILE_NAME1=%WAS_PROFILE_NAME%
set SERVER_NAME1=%WAS_SERVER_NAME%
)
IF "%DMGR_UPGRADE%"=="x" goto askdmgr
goto getmon

@rem Define input prompts for Toolkit
@rem Only need Monitor home because it is under WID. If we know WID home
@rem we can find Process Server home and the profile home.
:tkPrompt
call :logecho "Performing Monitor test server update for Toolkit"
set MON_PROMPT1=Type the path to the WebSphere Business Monitor Toolkit installation directory
set MON_PROMPT2=under the WebSphere Integration Developer (WID) directory
set MON_PROMPT=%MON_PROMPT1% %MON_PROMPT2%
set CELL_PROMPT=Type the cell name
set NODE_PROMPT=Type the node name

@rem Define default values for Toolkit
set MON_HOME=C:\IBM\WebSphere\ID\602\WBMonitor
if not "%WBMONITOR_HOME%"=="" set MON_HOME=%WBMONITOR_HOME%
@rem setupCmdLine.bat sets WAS_HOME which overrides our value, so use WAS_HOME1
set WAS_PROFILE_NAME=wbmonitor
for /F %%v in ('hostname') do set myhost=%%v
set CELL_NAME1=%myhost%Node01Cell
set NODE_NAME1=Node01
set SERVER_NAME1=server1
       
@rem Get Monitor home dir       
:getmon
set INPUT=
set /p INPUT=%MON_PROMPT% [enter=%MON_HOME%]: 
IF NOT "%INPUT%"=="" set MON_HOME=%INPUT%
if exist "%MON_HOME%" goto getwas
echo Monitor home - "%MON_HOME%" does not exist
call :logecho "Monitor home: %MON_HOME% does not exist"
set SAVE_RC=8
set MON_HOME=
goto getout

@rem Get WAS home dir       
:getwas
if "%INST_TK%"=="no" goto wasPrompt
@rem for Toolkit WAS home is based on Monitor home
set WID_HOME=%MON_HOME%\..

@rem Check if ITE was installed
set ITE_DIR=%MON_HOME%\_uninst
if NOT exist "%ITE_DIR%" goto skipMonitorServer

set WAS_HOME1=%WID_HOME%\runtimes\bi_v6
goto :chkwas
@rem For Monitor Server ask for WAS home
:wasPrompt
set INPUT=
set /p INPUT=%WAS_PROMPT% [enter=%WAS_HOME1%]: 
IF NOT "%INPUT%"=="" set WAS_HOME1=%INPUT%
:chkwas
if exist "%WAS_HOME1%" goto getprof
echo Process Server home - "%WAS_HOME1%" does not exist
call :logecho "Process Server home: %WAS_HOME1% does not exist"
set SAVE_RC=8
goto getout

@rem Get profile dir       
:getprof
if "%INST_TK%"=="no" goto profPrompt
@rem Set profile home default for Toolkit
set WAS_PROFILE_HOME=%WID_HOME%\pf\%WAS_PROFILE_NAME%
goto chkprof
@rem For Monitor Server ask for profile home
:profPrompt
set WAS_PROFILE_HOME=%WAS_HOME1%\profiles\%PROFILE_NAME1%
set INPUT=
set /p INPUT=%PROFILE_PROMPT% [enter=%WAS_PROFILE_HOME%]: 
IF NOT "%INPUT%"=="" set WAS_PROFILE_HOME=%INPUT%
:chkprof
if exist "%WAS_PROFILE_HOME%" goto getcell 
echo Profile home - "%WAS_PROFILE_HOME%" does not exist
call :logecho "Profile home: %WAS_PROFILE_HOME% does not exist"
set SAVE_RC=8
goto getout

@rem For Toolkit update, get the cell and node      
:getcell
if "%INST_TK%"=="no" goto getsrv

@rem Get cell name       
set INPUT=
set /p INPUT=%CELL_PROMPT% [enter=%CELL_NAME1%]: 
IF NOT "%INPUT%"=="" set CELL_NAME1=%INPUT%
if exist "%WAS_PROFILE_HOME%\config\cells\%CELL_NAME1%" goto getnode 
echo Cell home - "%WAS_PROFILE_HOME%\config\cells\%CELL_NAME1%" does not exist
call :logecho "Cell home - %WAS_PROFILE_HOME%\config\cells\%CELL_NAME1% does not exist"
set SAVE_RC=8
goto getout
 
@rem Get node name       
:getnode      
set INPUT=
set /p INPUT=%NODE_PROMPT% [enter=%NODE_NAME1%]: 
IF NOT "%INPUT%"=="" set NODE_NAME1=%INPUT%
if exist "%WAS_PROFILE_HOME%\config\cells\%CELL_NAME1%\nodes\%NODE_NAME1%" goto getsrv 
echo Node home - "%WAS_PROFILE_HOME%\config\cells\%CELL_NAME1%\nodes\%NODE_NAME1%" does not exist
call :logecho "Node home: %WAS_PROFILE_HOME%\config\cells\%CELL_NAME1%\nodes\%NODE_NAME1% does not exist"
set SAVE_RC=8
goto getout

@rem For Monitor Server update, get the server name      
:getsrv
if "%INST_TK%"=="yes" goto checkstamp
set INPUT=
set /p INPUT=%SERVER_PROMPT% [enter=%SERVER_NAME1%]: 
IF NOT "%INPUT%"=="" set SERVER_NAME1=%INPUT%
@rem setupCmdLine will set WAS_CELL and WAS_NODE
if exist "%WAS_PROFILE_HOME%\bin\setupCmdLine.bat" goto setupCmd
echo "%WAS_PROFILE_HOME%\bin\setupCmdLine.bat" does not exist
call :logecho "Node home: %WAS_PROFILE_HOME%\bin\setupCmdLine.bat does not exist"
set SAVE_RC=8
goto getout
:setupCmd
call "%WAS_PROFILE_HOME%\bin\setupCmdLine.bat"
@rem Verify that the server exists
set SERVER_HOME=%WAS_PROFILE_HOME%\config\cells\%WAS_CELL%\nodes\%WAS_NODE%\servers\%SERVER_NAME1%
if exist "%SERVER_HOME%" goto checkstamp
echo Server home - %SERVER_HOME% does not exist
call :logecho "Server home: %SERVER_HOME% does not exist"
set SAVE_RC=8
goto getout

:checkstamp
@rem ************************************************************************
@rem Look for stamp for this level in Monitor home; if found and backup
@rem directory is present then this level is already installed
@rem ************************************************************************
set MON_FIXPACK_DIR=%MON_HOME%\update\%MON_FIXPACK_INST%
if exist %MON_FIXPACK_DIR%\%MON_FIXPACK_STAMP% goto checkbackup
goto setup
:checkbackup
if not exist %MON_FIXPACK_DIR%\backups\monsrv goto setup
if "%INST_TK%"=="yes" goto tk_updated
echo This fixpack level (%MON_FIXPACK%) has already been installed for the Monitor server.
call :logecho "This fixpack level (%MON_FIXPACK%) has already been installed for the Monitor server."
goto cmdFailed
:tk_updated
echo This fixpack level (%MON_FIXPACK%) has already been installed for the Monitor Toolkit.
call :logecho "This fixpack level (%MON_FIXPACK%) has already been installed for the Monitor Toolkit."
goto cmdFailed

:setup 
@rem *********************************************************
@rem Stop the server
@rem *********************************************************
call "%WAS_PROFILE_HOME%\bin\setupCmdLine.bat" >>"%MY_LOG%" 2>&1
echo Stop server %SERVER_NAME1% ...
call :logecho "Stop server %SERVER_NAME1% ..."
call "%WAS_PROFILE_HOME%\bin\stopServer" %SERVER_NAME1% >>"%MY_LOG%" 2>&1

:createbackupdir
@rem *********************************************************
@rem Create directory for backing up files to be replaced
@rem *********************************************************
if exist "%MON_FIXPACK_BACKUP%" goto startupdate
set CMD=mkdir "%MON_FIXPACK_BACKUP%"
%CMD% >>"%MY_LOG%" 2>&1
if %errorlevel% NEQ 0 goto cmdFailed

:startupdate
@rem *********************************************************
@rem Update server jar files
@rem *********************************************************
echo Updating server jar files...
call :logecho "Updating server jar files..."
for %%f in (jars\*.*) do call :backupandreplace %%f "%WAS_HOME1%\lib"
if %errorlevel% NEQ 0 goto cmdFailed

@rem *********************************************************
@rem Update server plugins
@rem *********************************************************
echo Updating server plugins...
call :logecho "Updating server plugins..."
for /D %%f in (.\mme\plugins\*) do call :backupandreplaceplugins %%f "%WAS_HOME1%\deploytool\itp\plugins"
if %errorlevel% NEQ 0 goto cmdFailed

goto end
  
@rem ************************************************************************
@rem **************** Begin function definitions ****************************
REM ----------------------------------------------------------------------
REM  logecho
REM 
REM  write messages to log file
REM ----------------------------------------------------------------------
:logecho
echo ******************************************************** >> "%MY_LOG%"
echo %~1 >> "%MY_LOG%" 
echo ******************************************************** >> "%MY_LOG%"
time /t >> "%MY_LOG%" 
GOTO :EOF

REM ----------------------------------------------------------------------
REM  backupandreplace
REM
REM  Back up file being replaced, then copy in new one
REM  Don't copy file that doesn't exist in target
REM ----------------------------------------------------------------------
:backupandreplace
if not exist "%2"\%~nx1 goto backupandreplaceend
if not exist "%MON_FIXPACK_BACKUP%"\%~nx1 goto backup
echo Backup already created for %~nx1, don't overwrite >>"%MY_LOG%"
goto replace
:backup
set CMD=Xcopy /F /R /Y "%2"\%~nx1 "%MON_FIXPACK_BACKUP%"
%CMD% >>"%MY_LOG%" 2>&1
:replace
set CMD=XCopy /F /R /Y "%1" "%2"
%CMD% >>"%MY_LOG%" 2>&1
:backupandreplaceend
GOTO :EOF

REM ----------------------------------------------------------------------
REM  backupandreplaceplugins
REM
REM  Process a single plugin directory; back up directory being replaced,
REM  then copy in new one
REM  Don't copy directory that doesn't exist in target
REM ----------------------------------------------------------------------
:backupandreplaceplugins
if not exist "%2"\%~nx1 goto backupandreplacepluginsend
if not exist "%MON_FIXPACK_BACKUP%"\%~nx1 goto backup
echo Backup already created for %~nx1, don't overwrite >>"%MY_LOG%"
goto replace
:backup
set CMD=Xcopy /F /R /Y /S /I "%2"\%~nx1 "%MON_FIXPACK_BACKUP%"\%~nx1
%CMD% >>"%MY_LOG%" 2>&1
:replace
set CMD=XCopy /F /R /Y /S /I "%1" "%2"\%~nx1
%CMD% >>"%MY_LOG%" 2>&1
:backupandreplacepluginsend
GOTO :EOF

REM ----------------------------------------------------------------------
@rem **************** End function definitions ******************************
@rem ************************************************************************


@rem ************************************************************************
:skipMonitorServer
@rem ************************************************************************
set SAVE_RC=99
echo ITE is not installed. Skipping updates to the Monitor test server. >> %MY_LOG%
echo ITE is not installed. Skipping updates to the Monitor test server.
goto end2

@rem ************************************************************************
:cmdFailed
@rem ************************************************************************
set SAVE_RC=%errorlevel%
echo Error: command failed, error code = %errorlevel%
call :logecho "Error: command failed, return code = %errorlevel%"
goto getout

@rem ************************************************************************
:getout
@rem ************************************************************************
echo Update failed! 
call :logecho "Update failed!"
goto end2

@rem ************************************************************************
:end
@rem ************************************************************************
@rem Copy our stamp file to mark successful update to this level,
@rem then copy stamp and backups to Monitor home
@rem ************************************************************************
set CMD=XCopy /F /R /Y "version\*.*" "%MON_FIXPACK_INST%\"
%CMD% >>"%MY_LOG%" 2>&1
echo Copying backups and version info to Monitor home
call :logecho "Copying backups and version info to Monitor home"
set MON_FIXPACK_DIR=%MON_HOME%\update\%MON_FIXPACK_INST%
if exist "%MON_FIXPACK_DIR%" goto copybackups
mkdir "%MON_FIXPACK_DIR%"
:copybackups
set CMD=Xcopy /F /R /Y /S "%MON_FIXPACK_INST%" "%MON_FIXPACK_DIR%\"
%CMD% >>"%MY_LOG%" 2>&1

@rem ************************************************************************
@rem Restart the server (skip this for Toolkit update)
@rem ************************************************************************
if "%INST_TK%"=="yes" goto done
echo Start server %SERVER_NAME1% ... 
call :logecho "Start server %SERVER_NAME1% ..."
call "%WAS_PROFILE_HOME%\bin\startServer" %SERVER_NAME1% >>"%MY_LOG%" 2>&1
if %errorlevel% NEQ 0 goto cmdFailed

@rem ************************************************************************
:done
if "%INST_TK%"=="yes" goto tkfinished
set FINISH_MSG=Update finished.
goto finishmsg
:tkfinished
set FINISH_MSG=Test server update finished.
:finishmsg
echo %FINISH_MSG%
call :logecho "%FINISH_MSG%"
:end2

@rem Copy log file to Monitor home
IF ".%MON_HOME%"=="." goto skipcopy
set MON_LOG_DIR="%MON_HOME%\update\%MON_FIXPACK_INST%\logs"
if exist "%MON_LOG_DIR%" goto copylog 
mkdir "%MON_LOG_DIR%"
:copylog
xcopy /F /R /Y "%MY_LOG%" "%MON_LOG_DIR%\" >>nul 2>&1

:skipcopy
exit /b %SAVE_RC%
