@rem ************************************************************************
@rem  Licensed Material - Property of IBM
@rem 
@rem  5724-M24 
@rem 
@rem  (c) Copyright IBM Corp. 2007.  All rights reserved.
@rem 
@rem  US Government Users Restricted Rights - Use, duplication or
@rem  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@rem ************************************************************************

@rem ************************************************************************
@rem Update Monitor Development Toolkit 6.0.2.1 to iFix3 level
@rem This includes Toolkit IDE and ITE and Monitor (Test) Server
@rem ************************************************************************

@echo off
setlocal
set SAVE_RC=0
@rem Set up logs directory
SET TK_DIR=%CD%
if exist "%TK_DIR%\logs" goto setlog 
mkdir "%TK_DIR%\logs"
:setlog
set TK_LOG="%TK_DIR%\logs\toolkit.log"

@rem Define fixpack specific variables
set MON_FIXPACK_LEVEL=iFix3
set MON_FIXPACK=6.0.2.1-WBI-MONITOR-%MON_FIXPACK_LEVEL%
set MON_FIXPACK_INST=%MON_FIXPACK%.install
set MON_FIXPACK_TKBACKUP=%MON_FIXPACK_INST%\backups\toolkit
set MON_FIXPACK_STAMP=%MON_FIXPACK%.version

echo Start Monitor Development Toolkit 6.0.2.1 %MON_FIXPACK_LEVEL% update...
call :logecho "Start Monitor Development Toolkit 6.0.2.1 %MON_FIXPACK_LEVEL% update..."

@rem ************************************************************************
@rem Update Monitor Toolkit Test Server
@rem ************************************************************************
echo Update Monitor Toolkit test server ...
call :logecho "Update Monitor Toolkit test server ... Look at monsrv.log"
cd ..\monsrv
@rem NOTE: MON_HOME is set to Monitor Toolkit home by updateMonitorServer.bat
call updateMonitorServer.bat toolkit
set SAVE_RC=%errorlevel%
cd ..\toolkit
if %SAVE_RC% == 99 goto checkstamp
if %SAVE_RC% NEQ 0 goto cmdFailed

:checkstamp
@rem ************************************************************************
@rem Look for stamp for this level in Monitor Toolkit home; if found and
@rem backup directory is present then this level is already installed
@rem NOTE: A similar check is also performed in updateMonitorServer.bat, if
@rem the ITE is installed; if the ITE is not installed then that check will
@rem be bypassed so this check will detect fixpack installation for IDE only.
@rem ************************************************************************
set MON_FIXPACK_DIR=%MON_HOME%\update\%MON_FIXPACK_INST%
if exist %MON_FIXPACK_DIR%\%MON_FIXPACK_STAMP% goto checkbackup
goto createbackupdir
:checkbackup
if not exist %MON_FIXPACK_DIR%\backups\toolkit goto createbackupdir
echo This fixpack level (%MON_FIXPACK%) has already been installed for the Monitor Toolkit.
call :logecho "This fixpack level (%MON_FIXPACK%) has already been installed for the Monitor Toolkit."
goto cmdFailed

:createbackupdir
@rem ************************************************************************
@rem Create directory for backing up files to be replaced
@rem ************************************************************************
if exist "%MON_FIXPACK_TKBACKUP%" goto startupdate
set CMD=mkdir "%MON_FIXPACK_TKBACKUP%"
%CMD% >>"%MY_LOG%" 2>&1
set SAVE_RC=%errorlevel%
if %SAVE_RC% NEQ 0 goto cmdFailed

:startupdate
@rem ************************************************************************
@rem Update MME plugins
@rem ************************************************************************
echo Updating MME plugins...
call :logecho "Updating MME plugins..."
for /D %%f in (.\mme\plugins\*) do call :backupandreplaceplugins %%f "%MON_HOME%\mme\eclipse\plugins"
set SAVE_RC=%errorlevel%
if %SAVE_RC% NEQ 0 goto cmdFailed

goto end

@rem ************************************************************************
@rem **************** Begin function definitions ****************************
REM ----------------------------------------------------------------------
REM  logecho
REM 
REM  write messages to log file
REM ----------------------------------------------------------------------
:logecho
echo ******************************************************** >> "%TK_LOG%"
echo %~1 >> "%TK_LOG%"
echo ******************************************************** >> "%TK_LOG%"
time /t >> "%TK_LOG%" 
GOTO :EOF

REM ----------------------------------------------------------------------
REM  backupandreplaceplugins
REM
REM  Process a single plugin directory; back up directory being replaced,
REM  then copy in new one
REM  Don't copy directory that doesn't exist in target
REM ----------------------------------------------------------------------
:backupandreplaceplugins
if not exist "%2"\%~nx1 goto backupandreplacepluginsend
if not exist "%MON_FIXPACK_TKBACKUP%"\%~nx1 goto backup
echo Backup already created for %~nx1, don't overwrite >>"%TK_LOG%"
goto replace
:backup
set CMD=Xcopy /F /R /Y /S /I "%2"\%~nx1 "%MON_FIXPACK_TKBACKUP%"\%~nx1
%CMD% >>%TK_LOG% 2>&1
:replace
set CMD=XCopy /F /R /Y /S /I "%1" "%2"\%~nx1
%CMD% >>"%TK_LOG%" 2>&1
:backupandreplacepluginsend
GOTO :EOF

REM ----------------------------------------------------------------------
@rem **************** End function definitions ******************************
@rem ************************************************************************

@rem ************************************************************************
:cmdFailed
@rem ************************************************************************
echo Error: command failed, error code = %SAVE_RC%
call :logecho "Error: command failed, return code = %SAVE_RC%"
goto getout

@rem ************************************************************************
:getout
@rem ************************************************************************
echo Update failed! 
call :logecho "Update failed!"
goto end2

@rem ************************************************************************
:end
@rem ************************************************************************
@rem Copy our stamp file to mark successful update to this level,
@rem then copy stamp and backups to Monitor Toolkit home
@rem ************************************************************************
set CMD=XCopy /F /R /Y "version\*.*" "%MON_FIXPACK_INST%\"
%CMD% >>%TK_LOG% 2>&1
echo Copying backups and version info to Monitor Toolkit home
call :logecho "Copying backups and version info to Monitor Toolkit home"
set MON_FIXPACK_DIR="%MON_HOME%\update\%MON_FIXPACK_INST%"
if exist "%MON_FIXPACK_DIR%" goto copybackups
mkdir "%MON_FIXPACK_DIR%"
:copybackups
set CMD=Xcopy /F /R /Y /S "%MON_FIXPACK_INST%" "%MON_FIXPACK_DIR%\"
%CMD% >>%TK_LOG% 2>&1
@rem ************************************************************************
@rem WID must be launched with -clean option, do it
@rem automatically unless user declines
@rem ************************************************************************
set WID_HOME=%MON_HOME%\..
echo The next time you start WID, you should start it from a command window by going to the WID home directory
echo (%WID_HOME%) and typing "wid.exe -clean".
set INPUT=n
set /p INPUT=Would you like me to do that now [y or n, enter=n]?
if "%INPUT%"=="y" goto launchwidstart
call :logecho "WID auto-restart declined by user. The next time you start WID, you should start it from a command window by going to the WID home directory (%WID_HOME%) and typing 'wid.exe -clean'."
goto launchwidend
:launchwidstart
pushd %WID_HOME%
set CMD=wid.exe -clean
%CMD%
popd
echo WID is now launching to activate the updated MME plugins.  (This launch will take more time than a normal launch, so be patient.)  In the future you may launch WID as you normally would.
call :logecho "WID automatically launched with -clean option, updated MME plugins active"
:launchwidend
echo Update finished.
call :logecho "Update finished."
:end2

@rem Copy log file to Monitor Toolkit home
IF ".%MON_HOME%"=="." goto skipcopy
set MON_LOG_DIR="%MON_HOME%\update\%MON_FIXPACK_INST%\logs"
if exist "%MON_LOG_DIR%" goto copylog 
mkdir "%MON_LOG_DIR%"
:copylog
xcopy /F /R /Y "%TK_LOG%" "%MON_LOG_DIR%\"  >>nul 2>&1

:skipcopy
exit /b %SAVE_RC%
